import csv

def check_and_replenish(csv_file):
    """
    Checks stock levels from a CSV file and prints a list of items to order.
    The order quantity is calculated to be 1 more than the minimum quantity.
    """

    items_to_order = []

    try:
        with open(csv_file, 'r', newline='', encoding='utf-8') as file:
            reader = csv.DictReader(file)
            for row in reader:
                product_name = row.get('Product Name')
                min_qty_str = row.get('Minimum Qty')
                available_qty_str = row.get('Available Qty')
                brand = row.get('Brand')

                if min_qty_str and available_qty_str:
                    min_qty_str = min_qty_str.strip()
                    available_qty_str = available_qty_str.strip()
                    if min_qty_str and available_qty_str:
                        try:
                            min_qty = int(min_qty_str)
                            available_qty = int(available_qty_str)

                            if available_qty <= min_qty:
                                items_to_order.append({
                                    'brand': brand,
                                    'product_name': product_name,
                                    'order_qty': min_qty + 1 - available_qty # order quantity = min_qty + 1 - available qty
                                })
                        except ValueError:
                            print(f"Warning: Non-numeric quantity found for {product_name}. Skipping.")
                    else:
                        if product_name:
                            print(f"Warning: Empty quantity data for {product_name}. Skipping.")
                else:
                    if product_name:
                        print(f"Warning: Missing quantity data for {product_name}. Skipping.")

    except FileNotFoundError:
        print(f"Error: File '{csv_file}' not found.")
        return
    except KeyError as e:
        print(f"Error reading CSV: {e}")
        return

    if items_to_order:
        print("Items to order:")
        for item in items_to_order:
            print(f"- Brand: {item['brand']}")
            print(f"  Product Name: {item['product_name']}")
            print(f"  Order Quantity: {item['order_qty']}")
            print("------------------------")
    else:
        print("No items need replenishment.")

# Example usage:
csv_file_path = 'products.csv'
check_and_replenish(csv_file_path)

